from datetime import datetime
from collector_parsers.FileListParser import FileListParser
import json


class Collector:
    file_list_parser = FileListParser()
    data_dict = None
    finished_processes = None
    running_processes = {"processes": {}}

    def load_data(self):
        try:
            with open("/var/tmp/software_data.json", "r") as f:
                self.data_dict = json.load(f)
        except FileNotFoundError:
            self.data_dict = {"processes": {}}
        try:
            with open("/var/tmp/software_data_finished.json", "r") as f:
                self.finished_processes = json.load(f)
        except FileNotFoundError:
            self.finished_processes = {"processes": {}}

    def collect_process_info(self, processes):
        for proc in processes.values():
            self.file_list_parser.add_open_files_to_process(proc)
        return processes

    def write_process_info(self, processes):
        collected_processes = self.collect_process_info(processes)

        for loaded_process in self.data_dict["processes"]:
            incremented = False
            for process in collected_processes:
                if process == loaded_process:
                    self.data_dict["processes"][loaded_process]["running"] = True
                    self.data_dict["processes"][loaded_process]["time"] += 3
                    self.running_processes["processes"][loaded_process] = self.data_dict["processes"][loaded_process]
                    incremented = True
                    break
            if not incremented:
                self.data_dict["processes"][loaded_process]["running"] = False
                self.data_dict["processes"][loaded_process]["end_time"] = datetime.now().strftime("%H:%M")
                self.finished_processes["processes"][loaded_process] = self.data_dict["processes"][loaded_process]

        for process in collected_processes:
            found = False
            for loaded_process in self.data_dict["processes"]:
                if loaded_process == process:
                    found = True
            if not found:
                self.running_processes["processes"][process] = collected_processes[process]

        with open("/var/tmp/software_data.json", "w") as f:
            json.dump(self.running_processes, f)
        with open("/var/tmp/software_data_finished.json", "w") as f:
            json.dump(self.finished_processes, f)

        job_json = json.dumps(self.running_processes, indent=2)
        return job_json

    def group_data_by_user(self):
        output = {}
        for job in self.data_dict["jobs"]:
            if job["user"] not in output:
                output[job["user"]] = [job]
            else:
                output[job["user"]].append(job)
        job_json = json.dumps(output, indent=2)
        with open("user_data.json", "w") as f:
            json.dump(job_json, f)
        return job_json
